==> mdm-rpc-0.1.11-sources.jar: com/chinayanghe/msp/mdm/vo/org/OrgProductVo.java <==
package com.chinayanghe.msp.mdm.vo.org;

import java.util.Date;

/**
 * 组织与产品关系的Vo
 * Created by danDy on 2017/5/9.
 */
public class OrgProductVo {
    //主键
    private String id;
    //组织编码
    private String orgCode;
    //产品编码
    private String productCode;
    //创建人
    private String createName;
    //修改人
    private String updateName;
    //创建岗位编码
    private String createPosition;
    //修改岗位编码
    private String updatePosition;
    //创建时间
    private Date createDate;
    //修改时间
    private Date updateDate;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public String getUpdateName() {
        return updateName;
    }

    public void setUpdateName(String updateName) {
        this.updateName = updateName;
    }

    public String getCreatePosition() {
        return createPosition;
    }

    public void setCreatePosition(String createPosition) {
        this.createPosition = createPosition;
    }

    public String getUpdatePosition() {
        return updatePosition;
    }

    public void setUpdatePosition(String updatePosition) {
        this.updatePosition = updatePosition;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public Date getUpdateDate() {
        return updateDate;
    }

    public void setUpdateDate(Date updateDate) {
        this.updateDate = updateDate;
    }
}

==> mdm-rpc-0.1.93-sources.jar: com/chinayanghe/msp/mdm/vo/org/OrgProductVo.java <==
package com.chinayanghe.msp.mdm.vo.org;

import java.io.Serializable;
import java.util.Date;

/**
 * 组织与产品关系的Vo
 * Created by danDy on 2017/5/9.
 */
public class OrgProductVo implements Serializable {
    private static final long serialVersionUID = -1271691330125166774L;
    //主键
    private String id;
    //组织编码
    private String orgCode;
    //产品编码
    private String productCode;
    //创建人
    private String createName;
    //修改人
    private String updateName;
    //创建岗位编码
    private String createPosition;
    //修改岗位编码
    private String updatePosition;
    //创建时间
    private Date createDate;
    //修改时间
    private Date updateDate;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public String getUpdateName() {
        return updateName;
    }

    public void setUpdateName(String updateName) {
        this.updateName = updateName;
    }

    public String getCreatePosition() {
        return createPosition;
    }

    public void setCreatePosition(String createPosition) {
        this.createPosition = createPosition;
    }

    public String getUpdatePosition() {
        return updatePosition;
    }

    public void setUpdatePosition(String updatePosition) {
        this.updatePosition = updatePosition;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public Date getUpdateDate() {
        return updateDate;
    }

    public void setUpdateDate(Date updateDate) {
        this.updateDate = updateDate;
    }
}
